@@ -9,7 +9,7 @@ import sys
 import threading
 from contextlib import AsyncExitStack
 from datetime import datetime
-from typing import Any, Awaitable, Callable, List, Optional, Sequence, Tuple
+from typing import Any, Awaitable, Callable, List, NoReturn, Optional, Sequence, Tuple
 
 import aiohttp
 import click
@@ -21,7 +21,6 @@ from prompt_toolkit.key_binding.key_processor import KeyPressEvent
 from prompt_toolkit.keys import Keys
 from prompt_toolkit.output import Output, create_output
 from prompt_toolkit.shortcuts import PromptSession
-from typing_extensions import NoReturn
 
 from neuro_sdk import (
     JobDescription,
