@@ -6,16 +6,25 @@ from rich.console import Group as RichGroup
 from rich.console import RenderableType
 from rich.rule import Rule
 from rich.styled import Styled
-from rich.table import Table
+from rich.table import Column, Table
+from rich.text import Text
 
 from neuro_sdk import (
+    _AWSStorageOptions,
+    _AzureStorageOptions,
+    _CloudProviderOptions,
+    _CloudProviderType,
     _Cluster,
     _ClusterUserWithInfo,
     _ConfigCluster,
+    _GoogleStorageOptions,
     _NodePool,
+    _NodePoolOptions,
     _Org,
     _OrgCluster,
     _OrgUserWithInfo,
+    _Project,
+    _ProjectUserWithInfo,
     _Storage,
 )
 
@@ -174,17 +183,21 @@ class ClustersFormatter:
                 table.add_row("Status", config_cluster.status.capitalize())
                 if config_cluster.cloud_provider:
                     cloud_provider = config_cluster.cloud_provider
-                    if cloud_provider.type != "on_prem":
+                    region = getattr(cloud_provider, "region", "")
+                    zones = getattr(cloud_provider, "zones", "")
+                    if cloud_provider.type != _CloudProviderType.ON_PREM:
                         table.add_row("Cloud", cloud_provider.type)
-                    if cloud_provider.region:
-                        table.add_row("Region", cloud_provider.region)
-                    if cloud_provider.zones:
-                        table.add_row("Zones", ", ".join(cloud_provider.zones))
+                    if region:
+                        table.add_row("Region", region)
+                    if zones:
+                        table.add_row("Zones", ", ".join(zones))
                     if cloud_provider.node_pools:
                         table.add_row(
                             "Node pools",
                             Styled(
-                                _format_node_pools(cloud_provider.node_pools),
+                                _format_node_pools(
+                                    cloud_provider.type, cloud_provider.node_pools
+                                ),
                                 style="reset",
                             ),
                         )
@@ -217,7 +230,9 @@ class ClustersFormatter:
         return RichGroup(*out)
 
 
-def _format_node_pools(node_pools: Iterable[_NodePool]) -> Table:
+def _format_node_pools(
+    type: _CloudProviderType, node_pools: Iterable[_NodePool]
+) -> Table:
     is_scalable = _is_scalable(node_pools)
     has_preemptible = _has_preemptible(node_pools)
     has_idle = _has_idle(node_pools)
@@ -226,7 +241,9 @@ def _format_node_pools(node_pools: Iterable[_NodePool]) -> Table:
         box=box.SIMPLE_HEAVY,
         show_edge=True,
     )
-    table.add_column("Machine", style="bold", justify="left")
+    table.add_column("Name", style="bold", justify="left")
+    if type != _CloudProviderType.ON_PREM:
+        table.add_column("Machine", style="bold", justify="left")
     table.add_column("CPU", justify="right")
     table.add_column("Memory", justify="right")
     table.add_column("Disk", justify="right")
@@ -242,11 +259,11 @@ def _format_node_pools(node_pools: Iterable[_NodePool]) -> Table:
         table.add_column("Idle", justify="right")
 
     for node_pool in node_pools:
-        row = [
-            node_pool.machine_type,
-            str(node_pool.available_cpu),
-            format_size(node_pool.available_memory),
-        ]
+        row = [node_pool.name]
+        if type != _CloudProviderType.ON_PREM:
+            row.append(node_pool.machine_type or "")
+        row.append(str(node_pool.available_cpu))
+        row.append(format_size(node_pool.available_memory))
         if node_pool.disk_type:
             row.append(
                 f"{format_size(node_pool.disk_size)} " f"{node_pool.disk_type.upper()}"
@@ -260,7 +277,7 @@ def _format_node_pools(node_pools: Iterable[_NodePool]) -> Table:
             row.append(str(node_pool.min_size))
         row.append(str(node_pool.max_size))
         if has_idle:
-            row.append(str(node_pool.idle_size))
+            row.append(str(node_pool.idle_size or 0))
         table.add_row(*row)
 
     return table
@@ -281,7 +298,7 @@ def _format_storage(storage: _Storage) -> Table:
     else:
         has_size = False
     for instance in storage.instances:
-        row = [instance.name or "<default>", storage.description]
+        row = [instance.name or "<default>", getattr(storage, "description", "")]
         if has_size:
             if instance.size is None:
                 row.append("")
@@ -325,3 +342,181 @@ class OrgsFormatter:
         for org in orgs:
             table.add_row(org.name)
         return table
+
+
+class CloudProviderOptionsFormatter:
+    def __call__(self, options: _CloudProviderOptions) -> RenderableType:
+        out: list[RenderableType] = []
+        table = Table(
+            Column("Id"),
+            Column("Machine"),
+            Column("CPU"),
+            Column("CPU Avail"),
+            Column("Memory"),
+            Column("Memory Avail"),
+            Column("GPU"),
+            title="Available node pools:",
+            title_justify="left",
+            title_style="bold italic",
+            box=box.SIMPLE_HEAVY,
+            show_edge=False,
+        )
+        for np in options.node_pools:
+            table.add_row(
+                np.id,
+                np.machine_type,
+                str(np.cpu),
+                str(np.available_cpu),
+                format_size(np.memory),
+                format_size(np.available_memory),
+                self._gpu(np),
+            )
+        out.append(table)
+        out.append(Text())
+        if options.type == _CloudProviderType.AWS:
+            out.append(self._format_aws_storages(options.storages))  # type: ignore
+        elif options.type == _CloudProviderType.GCP:
+            out.append(self._format_google_storages(options.storages))  # type: ignore
+        elif options.type == _CloudProviderType.AZURE:
+            out.append(self._format_azure_storages(options.storages))  # type: ignore
+        else:
+            out.pop()
+        return RichGroup(*out)
+
+    def _gpu(self, node_pool: _NodePoolOptions) -> str:
+        if node_pool.gpu:
+            return f"{node_pool.gpu} x {node_pool.gpu_model}"
+        return ""
+
+    def _format_aws_storages(self, storages: Iterable[_AWSStorageOptions]) -> Table:
+        table = Table(
+            Column("Id"),
+            Column("Performance"),
+            Column("Throughput"),
+            box=box.SIMPLE_HEAVY,
+            show_edge=False,
+            title="Available storages:",
+            title_justify="left",
+            title_style="bold italic",
+        )
+        for s in storages:
+            table.add_row(s.id, s.performance_mode, s.throughput_mode)
+        return table
+
+    def _format_google_storages(
+        self, storages: Iterable[_GoogleStorageOptions]
+    ) -> Table:
+        table = Table(
+            Column("Id"),
+            Column("Tier"),
+            Column("Capacity"),
+            box=box.SIMPLE_HEAVY,
+            show_edge=False,
+            title="Available storages:",
+            title_justify="left",
+            title_style="bold italic",
+        )
+        for s in storages:
+            min_capacity = format_size(s.min_capacity)
+            max_capacity = format_size(s.max_capacity)
+            table.add_row(s.id, s.tier.capitalize(), f"{min_capacity} - {max_capacity}")
+        return table
+
+    def _format_azure_storages(self, storages: Iterable[_AzureStorageOptions]) -> Table:
+        table = Table(
+            Column("Id"),
+            Column("Tier"),
+            Column("Replication"),
+            Column("Capacity"),
+            box=box.SIMPLE_HEAVY,
+            show_edge=False,
+            title="Available storages:",
+            title_justify="left",
+            title_style="bold italic",
+        )
+        for s in storages:
+            min_capacity = format_size(s.min_file_share_size)
+            max_capacity = format_size(s.max_file_share_size)
+            table.add_row(
+                s.id,
+                s.tier.capitalize(),
+                s.replication_type,
+                f"{min_capacity} - {max_capacity}",
+            )
+        return table
+
+
+class ProjectsFormatter:
+    def __call__(self, projects: Iterable[_Project]) -> RenderableType:
+        table = Table(box=box.MINIMAL_HEAVY_HEAD)
+        table.add_column("Project name", style="bold")
+        table.add_column("Cluster name")
+        table.add_column("Org name")
+        table.add_column("Default role")
+        table.add_column("Is default project")
+        rows = []
+
+        for project in projects:
+            rows.append(
+                (
+                    project.name,
+                    project.cluster_name,
+                    project.org_name,
+                    project.default_role.value,
+                    str(project.is_default),
+                )
+            )
+        rows.sort(key=operator.itemgetter(0))
+
+        for row in rows:
+            table.add_row(*row)
+        return table
+
+
+class ProjectFormatter:
+    def __call__(
+        self, project: _Project, *, skip_cluster_org: bool = False
+    ) -> RenderableType:
+        table = Table(box=None, show_header=False, show_edge=False)
+        table.add_column()
+        table.add_column(style="bold")
+        table.add_row("Name", project.name)
+        if not skip_cluster_org:
+            table.add_row("Cluster name", project.cluster_name)
+            table.add_row("Org name", project.org_name)
+        table.add_row(
+            "Default role",
+            project.default_role.value,
+        )
+        table.add_row(
+            "Is default project",
+            str(project.is_default),
+        )
+        return table
+
+
+class ProjectUserFormatter:
+    def __call__(self, project_users: Iterable[_ProjectUserWithInfo]) -> RenderableType:
+        table = Table(box=box.MINIMAL_HEAVY_HEAD)
+        table.add_column("Name", style="bold")
+        table.add_column("Role")
+        table.add_column("Email")
+        table.add_column("Full name")
+        table.add_column("Registered")
+        rows = []
+
+        for user in project_users:
+            rows.append(
+                (
+                    user.user_name,
+                    user.role.value,
+                    user.user_info.email,
+                    user.user_info.full_name,
+                    format_datetime_iso(user.user_info.created_at),
+                )
+            )
+        rows.sort(key=operator.itemgetter(0))
+
+        for row in rows:
+            table.add_row(*row)
+        return table
