@@ -16,7 +16,7 @@ def revoke(helper: Helper, uri: str, username: str) -> None:
 
 @pytest.mark.e2e
 def test_grant_complete_lifecycle(request: Any, helper: Helper) -> None:
-    uri = f"storage://{helper.cluster_name}/{helper.username}/{uuid4()}"
+    uri = f"storage://{helper.cluster_uri_base}/{uuid4()}"
     uri2 = f"{uri}/{uuid4()}"
 
     another_test_user = "test2"
@@ -37,7 +37,7 @@ def test_grant_complete_lifecycle(request: Any, helper: Helper) -> None:
     assert captured.err == ""
     result = [line.split() for line in captured.out.splitlines()]
     assert [
-        f"storage://{helper.cluster_name}/{helper.username}",
+        f"storage://{helper.cluster_uri_base}",
         "manage",
     ] in result or [f"storage://{helper.cluster_name}", "manage"] in result
     assert [f"user://{helper.username}", "read"] in result
@@ -46,7 +46,7 @@ def test_grant_complete_lifecycle(request: Any, helper: Helper) -> None:
     assert captured.err == ""
     result = [line.split() for line in captured.out.splitlines()]
     assert [
-        f"storage://{helper.cluster_name}/{helper.username}",
+        f"storage://{helper.cluster_uri_base}",
         "manage",
     ] in result or [f"storage://{helper.cluster_name}", "manage"] in result
     for line in result:
@@ -95,7 +95,7 @@ def test_grant_complete_lifecycle(request: Any, helper: Helper) -> None:
 
 @pytest.mark.e2e
 def test_revoke_no_effect(helper: Helper) -> None:
-    uri = f"storage://{helper.cluster_name}/{helper.username}/{uuid4()}"
+    uri = f"storage://{helper.cluster_uri_base}/{uuid4()}"
     with pytest.raises(subprocess.CalledProcessError) as cm:
         helper.run_cli(["-v", "acl", "revoke", uri, "public"])
     assert cm.value.returncode == 127
@@ -107,7 +107,7 @@ def test_revoke_no_effect(helper: Helper) -> None:
 def test_grant_image_no_tag(request: Any, helper: Helper) -> None:
     rel_path = str(uuid4())
     rel_uri = f"image:{rel_path}"
-    uri = f"image://{helper.cluster_name}/{helper.username}/{rel_path}"
+    uri = f"image://{helper.cluster_uri_base}/{rel_path}"
     another_test_user = "test2"
 
     request.addfinalizer(lambda: revoke(helper, rel_uri, another_test_user))
@@ -125,7 +125,7 @@ def test_grant_image_no_tag(request: Any, helper: Helper) -> None:
 
 @pytest.mark.e2e
 def test_grant_image_with_tag_fails(request: Any, helper: Helper) -> None:
-    uri = f"image://{helper.cluster_name}/{helper.username}/{uuid4()}:latest"
+    uri = f"image://{helper.cluster_uri_base}/{uuid4()}:latest"
     another_test_user = "test2"
     with pytest.raises(subprocess.CalledProcessError) as cm:
         request.addfinalizer(lambda: revoke(helper, uri, another_test_user))
@@ -161,7 +161,7 @@ def test_add_grant_remove_role(request: Any, helper: Helper) -> None:
         assert captured.err == ""
         assert captured.out == ""
 
-        uri = f"storage://{helper.cluster_name}/{helper.username}/{uuid4()}"
+        uri = f"storage://{helper.cluster_uri_base}/{uuid4()}"
         captured = helper.run_cli(["acl", "grant", uri, role_name, "read"])
         assert captured.err == ""
         assert captured.out == ""
