@@ -34,7 +34,7 @@ def test_prompt_cluster(make_client: Callable[..., Client]) -> None:
             buckets_url=URL("https://buckets-dev.neu.ro"),
             presets={
                 "cpu-small": Preset(
-                    credits_per_hour=Decimal("10"), cpu=1, memory_mb=1024
+                    credits_per_hour=Decimal("10"), cpu=1, memory=2**30
                 )
             },
             name="first",
@@ -50,7 +50,7 @@ def test_prompt_cluster(make_client: Callable[..., Client]) -> None:
             buckets_url=URL("https://buckets2-dev.neu.ro"),
             presets={
                 "cpu-small": Preset(
-                    credits_per_hour=Decimal("10"), cpu=2, memory_mb=1024
+                    credits_per_hour=Decimal("10"), cpu=2, memory=2**30
                 )
             },
             name="second",
@@ -108,7 +108,7 @@ def test_prompt_cluster_default(make_client: Callable[..., Client]) -> None:
             buckets_url=URL("https://buckets-dev.neu.ro"),
             presets={
                 "cpu-small": Preset(
-                    credits_per_hour=Decimal("10"), cpu=1, memory_mb=1024
+                    credits_per_hour=Decimal("10"), cpu=1, memory=2**30
                 )
             },
             name="first",
@@ -124,7 +124,7 @@ def test_prompt_cluster_default(make_client: Callable[..., Client]) -> None:
             buckets_url=URL("https://disks2-dev.neu.ro"),
             presets={
                 "cpu-small": Preset(
-                    credits_per_hour=Decimal("10"), cpu=2, memory_mb=1024
+                    credits_per_hour=Decimal("10"), cpu=2, memory=2**30
                 )
             },
             name="second",
